@@ -5,10 +5,7 @@ import os
 import sys
 import unittest
 
-import six
-
 import cherrypy
-import cherrypy._cpcompat as compat
 
 from cherrypy.test import helper
 
@@ -17,7 +14,7 @@ localDir = os.path.join(os.getcwd(), os.path.dirname(__file__))
 
 
 def StringIOFromNative(x):
-    return io.StringIO(six.text_type(x))
+    return io.StringIO(str(x))
 
 
 def setup_server():
@@ -106,18 +103,12 @@ def setup_server():
         def incr(self, num):
             return num + 1
 
-    if not six.PY3:
-        thing3 = "thing3: unicode('test', errors='ignore')"
-    else:
-        thing3 = ''
-
     ioconf = StringIOFromNative("""
 [/]
 neg: -1234
 filename: os.path.join(sys.prefix, "hello.py")
 thing1: cherrypy.lib.httputil.response_codes[404]
 thing2: __import__('cherrypy.tutorial', globals(), locals(), ['']).thing2
-%s
 complex: 3+2j
 mul: 6*3
 ones: "11"
@@ -126,7 +117,7 @@ stradd: %%(ones)s + %%(twos)s + "33"
 
 [/favicon.ico]
 tools.staticfile.filename = %r
-""" % (thing3, os.path.join(localDir, 'static/dirback.jpg')))
+""" % os.path.join(localDir, 'static/dirback.jpg'))
 
     root = Root()
     root.foo = Foo()
@@ -204,10 +195,6 @@ class ConfigTests(helper.CPWebCase):
             from cherrypy.tutorial import thing2
             self.assertBody(repr(thing2))
 
-        if not six.PY3:
-            self.getPage('/repr?key=thing3')
-            self.assertBody(repr(six.text_type('test')))
-
         self.getPage('/repr?key=complex')
         self.assertBody('(3+2j)')
 
@@ -241,7 +228,7 @@ class ConfigTests(helper.CPWebCase):
         self.getPage('/plain', method='POST', headers=[
             ('Content-Type', 'application/x-www-form-urlencoded'),
             ('Content-Length', '13')],
-            body=compat.ntob('\xff\xfex\x00=\xff\xfea\x00b\x00c\x00'))
+            body=b'\xff\xfex\x00=\xff\xfea\x00b\x00c\x00')
         self.assertBody('abc')
 
 
